# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.4.1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.invitation_request import InvitationRequest

class TestInvitationRequest(unittest.TestCase):
    """InvitationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvitationRequest:
        """Test InvitationRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvitationRequest`
        """
        model = InvitationRequest()
        if include_optional:
            return InvitationRequest(
                name = 'z0',
                expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                fixed_data = {
                    'key' : null
                    },
                single_use = True,
                flow = ''
            )
        else:
            return InvitationRequest(
                name = 'z0',
        )
        """

    def testInvitationRequest(self):
        """Test InvitationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
