# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.4.1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.outpost_health import OutpostHealth

class TestOutpostHealth(unittest.TestCase):
    """OutpostHealth unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OutpostHealth:
        """Test OutpostHealth
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OutpostHealth`
        """
        model = OutpostHealth()
        if include_optional:
            return OutpostHealth(
                uid = '',
                last_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                version = '',
                golang_version = '',
                openssl_enabled = True,
                openssl_version = '',
                fips_enabled = True,
                version_should = '',
                version_outdated = True,
                build_hash = '',
                build_hash_should = '',
                hostname = ''
            )
        else:
            return OutpostHealth(
                uid = '',
                last_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                version = '',
                golang_version = '',
                openssl_enabled = True,
                openssl_version = '',
                fips_enabled = True,
                version_should = '',
                version_outdated = True,
                build_hash = '',
                build_hash_should = '',
                hostname = '',
        )
        """

    def testOutpostHealth(self):
        """Test OutpostHealth"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
