# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.4.1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.paginated_authenticator_web_authn_stage_list import PaginatedAuthenticatorWebAuthnStageList

class TestPaginatedAuthenticatorWebAuthnStageList(unittest.TestCase):
    """PaginatedAuthenticatorWebAuthnStageList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedAuthenticatorWebAuthnStageList:
        """Test PaginatedAuthenticatorWebAuthnStageList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedAuthenticatorWebAuthnStageList`
        """
        model = PaginatedAuthenticatorWebAuthnStageList()
        if include_optional:
            return PaginatedAuthenticatorWebAuthnStageList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.authenticator_web_authn_stage.AuthenticatorWebAuthnStage(
                        pk = '', 
                        name = '', 
                        component = '', 
                        verbose_name = '', 
                        verbose_name_plural = '', 
                        meta_model_name = '', 
                        flow_set = [
                            authentik_client.models.flow_set.FlowSet(
                                pk = '', 
                                policybindingmodel_ptr_id = '', 
                                name = '', 
                                slug = 'z', 
                                title = '', 
                                designation = null, 
                                background = '', 
                                policy_engine_mode = 'all', 
                                compatibility_mode = True, 
                                export_url = '', 
                                layout = 'stacked', 
                                denied_action = null, )
                            ], 
                        configure_flow = '', 
                        friendly_name = '', 
                        user_verification = 'required', 
                        authenticator_attachment = null, 
                        resident_key_requirement = 'discouraged', 
                        device_type_restrictions = [
                            ''
                            ], 
                        device_type_restrictions_obj = [
                            authentik_client.models.web_authn_device_type.WebAuthnDeviceType(
                                aaguid = '', 
                                description = '', )
                            ], )
                    ]
            )
        else:
            return PaginatedAuthenticatorWebAuthnStageList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.authenticator_web_authn_stage.AuthenticatorWebAuthnStage(
                        pk = '', 
                        name = '', 
                        component = '', 
                        verbose_name = '', 
                        verbose_name_plural = '', 
                        meta_model_name = '', 
                        flow_set = [
                            authentik_client.models.flow_set.FlowSet(
                                pk = '', 
                                policybindingmodel_ptr_id = '', 
                                name = '', 
                                slug = 'z', 
                                title = '', 
                                designation = null, 
                                background = '', 
                                policy_engine_mode = 'all', 
                                compatibility_mode = True, 
                                export_url = '', 
                                layout = 'stacked', 
                                denied_action = null, )
                            ], 
                        configure_flow = '', 
                        friendly_name = '', 
                        user_verification = 'required', 
                        authenticator_attachment = null, 
                        resident_key_requirement = 'discouraged', 
                        device_type_restrictions = [
                            ''
                            ], 
                        device_type_restrictions_obj = [
                            authentik_client.models.web_authn_device_type.WebAuthnDeviceType(
                                aaguid = '', 
                                description = '', )
                            ], )
                    ],
        )
        """

    def testPaginatedAuthenticatorWebAuthnStageList(self):
        """Test PaginatedAuthenticatorWebAuthnStageList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
