# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.4.1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.o_auth_source_request import OAuthSourceRequest

class TestOAuthSourceRequest(unittest.TestCase):
    """OAuthSourceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OAuthSourceRequest:
        """Test OAuthSourceRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OAuthSourceRequest`
        """
        model = OAuthSourceRequest()
        if include_optional:
            return OAuthSourceRequest(
                name = '0',
                slug = 'z0',
                enabled = True,
                authentication_flow = '',
                enrollment_flow = '',
                user_property_mappings = [
                    ''
                    ],
                group_property_mappings = [
                    ''
                    ],
                policy_engine_mode = 'all',
                user_matching_mode = 'identifier',
                user_path_template = '0',
                group_matching_mode = 'identifier',
                provider_type = 'apple',
                request_token_url = '',
                authorization_url = '',
                access_token_url = '',
                profile_url = '',
                consumer_key = '0',
                consumer_secret = '0',
                additional_scopes = '',
                oidc_well_known_url = '',
                oidc_jwks_url = '',
                oidc_jwks = None,
                authorization_code_auth_method = 'basic_auth'
            )
        else:
            return OAuthSourceRequest(
                name = '0',
                slug = 'z0',
                provider_type = 'apple',
                consumer_key = '0',
                consumer_secret = '0',
        )
        """

    def testOAuthSourceRequest(self):
        """Test OAuthSourceRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
