# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.4.1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.blueprint_instance_status_enum import BlueprintInstanceStatusEnum

class TestBlueprintInstanceStatusEnum(unittest.TestCase):
    """BlueprintInstanceStatusEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBlueprintInstanceStatusEnum(self):
        """Test BlueprintInstanceStatusEnum"""
        # inst = BlueprintInstanceStatusEnum()

if __name__ == '__main__':
    unittest.main()
