# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.4.1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.authenticator_validate_stage_request import AuthenticatorValidateStageRequest

class TestAuthenticatorValidateStageRequest(unittest.TestCase):
    """AuthenticatorValidateStageRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthenticatorValidateStageRequest:
        """Test AuthenticatorValidateStageRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthenticatorValidateStageRequest`
        """
        model = AuthenticatorValidateStageRequest()
        if include_optional:
            return AuthenticatorValidateStageRequest(
                name = '0',
                flow_set = [
                    authentik_client.models.flow_set_request.FlowSetRequest(
                        name = '0', 
                        slug = 'z0', 
                        title = '0', 
                        designation = null, 
                        policy_engine_mode = 'all', 
                        compatibility_mode = True, 
                        layout = 'stacked', 
                        denied_action = null, )
                    ],
                not_configured_action = 'skip',
                device_classes = [
                    'static'
                    ],
                configuration_stages = [
                    ''
                    ],
                last_auth_threshold = '0',
                webauthn_user_verification = 'required',
                webauthn_allowed_device_types = [
                    ''
                    ]
            )
        else:
            return AuthenticatorValidateStageRequest(
                name = '0',
        )
        """

    def testAuthenticatorValidateStageRequest(self):
        """Test AuthenticatorValidateStageRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
